#
# spec file for package python-jedi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jedi
Version:        0.19.2
Release:        1.4
Summary:        An autocompletion tool for Python
License:        MIT AND Python-2.0
URL:            https://github.com/davidhalter/jedi
Source0:        https://files.pythonhosted.org/packages/source/j/jedi/jedi-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# The author of jedi and parso takes pinning very seriously, adhere to it!
BuildRequires:  %{python_module parso >= 0.8.4 with %python-parso < 0.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# See pinning note above
Requires:       (python-parso >= 0.8.4 with python-parso < 0.9)
BuildArch:      noarch
%python_subpackages

%description
Jedi is a static analysis tool for Python that can be used in
IDEs/editors. Its focus is autocompletion and static
analysis.

Jedi has support for two different goto functions. It's possible to
search for related names and to list all names in a Python file and
infer them. Jedi understands docstrings and you can use Jedi
autocompletion in your REPL as well.

Jedi uses an API to connect with IDEs. There is a reference
implementation as a VIM plugin which uses Jedi's autocompletion.

%prep
%autosetup -p1 -n jedi-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG="en_US.UTF-8"
skiptests="test_venv_and_pths"
skiptests+=" or test_sqlite3_conversion"
# some architectures are too slow for these optimizer devel checks
skiptests+=" or test_speed"
# fails on some architectures
skiptests+=" or test_init_extension_module"
# This fails on 15.4_py39 server-side but not locally (!?)
skiptests+=" or test_get_default_environment_when_embedded"
%pytest -k "not ($skiptests)"

%files %{python_files}
%doc AUTHORS.txt CHANGELOG.rst README.rst
%license LICENSE.txt
%{python_sitelib}/jedi
%{python_sitelib}/jedi-%{version}.dist-info

%changelog
* Mon Dec  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.19.2
  * Python 3.13 support
- Drop python3.13-support.patch, merged upstream
* Fri Sep 20 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick patch from Fedora to add support for Python 3.13
  * python3.13-support.patch
* Tue Oct 17 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.19.1:
  * Python 3.12 support
- Stop skipping some tests.
* Thu Aug 10 2023 Benjamin Greiner <code@bnavigator.de>
- Update requirements
* Thu Aug 10 2023 Arun Persaud <arun@gmx.de>
- specfile:
  * remove patch supported_pythons_310_311.patch, included upstream
  * remove patch support-python-311-typing.patch, included upstreamx
- update to version 0.19.0:
  * Python 3.11 support
  * Massive improvements in performance for Interpreter (e.g. IPython)
    users. This especially affects pandas users with large datasets.
  * Add jedi.settings.allow_unsafe_interpreter_executions to make it
    easier for IPython users to avoid unsafe executions.
* Wed May 10 2023 Ben Greiner <code@bnavigator.de>
- Skip a test failing with attrs 23.1
  * gh#davidhalter/jedi#1929
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Feb 13 2023 Ben Greiner <code@bnavigator.de>
- Remove fix_test_compiled_signature_annotation_string.patch
  All tests pass without it
* Sun Feb 12 2023 Matej Cepl <mcepl@suse.com>
- Add supported_pythons_310_311.patch which includes '3.11' among
  _SUPPORTED_PYTHONS (gh#davidhalter/jedi#1914).
* Sat Feb 11 2023 Matej Cepl <mcepl@suse.com>
- Add fix_test_compiled_signature_annotation_string.patch to make
  test passing with Python 3.10+ (gh#davidhalter/jedi#1732).
* Tue Jan 10 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python-311-typing.patch:
  * Support typing changes for Python 3.11+
* Tue Jan  3 2023 Ben Greiner <code@bnavigator.de>
- Move to PEP517
- Pin parso like upstream does
- Skip a test for embedded systems which unexplicably fails on
  backports 15.4_py39
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.18.2
  * Added dataclass-equivalent for attrs.define
  * Find fixtures from Pytest entrypoints; Examples of pytest plugins installed like this are pytest-django, pytest-sugar and Faker.
  * Fixed Project.search, when a venv was involved, which is why for example :Pyimport django.db did not work in some cases in jedi-vim.
  * And many smaller bugfixes
* Sun Mar 27 2022 Ben Greiner <code@bnavigator.de>
- Skip two test failing with pytest 7.1 -- gh#davidhalter/jedi#1846
* Mon Jan 10 2022 Benjamin Greiner <code@bnavigator.de>
- Force pytest >= 5 for successful 15.3 build in d:l:p
* Fri Dec 10 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.18.1
  * Implict namespaces are now a separate types in Name().type
  * Python 3.10 support
  * Mostly bugfixes
- Drop jedi-py39-pytest.patch
- Skip failing test (reported as gh#davidhalter/jedi#1824)
* Sun Oct 31 2021 Benjamin Greiner <code@bnavigator.de>
- Force pytest5 because it has the pluggy<1 pin patched out
* Sat Mar 13 2021 Ben Greiner <code@bnavigator.de>
- Add jedi-py39-pytest.patch to support Python 3.9
* Fri Dec 25 2020 Matej Cepl <mcepl@suse.com>
- update to 0.18.0 (get it together with the latest python-parso just to
  be sure):
  - Dropped Python 2 and Python 3.5
  - Using ``pathlib.Path()`` as an output instead of ``str`` in most
    places:
  - ``Project.path``
  - ``Script.path``
  - ``Definition.module_path``
  - ``Refactoring.get_renames``
  - ``Refactoring.get_changed_files``
  - Functions with ``@property`` now return ``property`` instead of
    ``function`` in ``Name().type``
  - Started using annotations
  - Better support for the walrus operator
  - Project attributes are now read accessible
  - Removed all deprecations
  This is likely going to be the last minor release before 1.0.
* Thu Sep  3 2020 Matej Cepl <mcepl@suse.com>
- Revert back to 0.17.2.
* Thu Aug 27 2020 Benjamin Greiner <code@bnavigator.de>
- Exclude pytest 6 gh#davidhalter/jedi#1660
* Fri Jul 17 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 0.17.2
  * Added an option to pass environment variables to ``Environment``
  * ``Project(...).path`` exists now
  * Support for Python 3.9
  * A few bugfixes
- rpmlint zero length django-stubs
* Sat Jun 20 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 0.17.1
  * Django ``Model`` meta class support
  * Django Manager support (completion on Managers/QuerySets)
  * Added Django Stubs to Jedi, thanks to all contributors of the
    `Django Stubs <https://github.com/typeddjango/django-stubs>`_ project
  * Added ``SyntaxError.get_message``
  * Python 3.9 support
  * Bugfixes (mostly towards Generics)
- drop jedi-pr1543-sorttest.patch merged upstream
* Sun May 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip two tests on leap not just sp1+
* Wed Apr 15 2020 Benjamin Greiner <code@bnavigator.de>
- Update to v0.17.0
  * Added ``Project`` support. This allows a user to specify which
    folders Jedi should work with.
  * Added support for Refactoring. The following refactorings have
    been implemented: ``Script.rename``, ``Script.inline``,
    ``Script.extract_variable`` and ``Script.extract_function``.
  * Added ``Script.get_syntax_errors`` to display syntax errors in
    the current script.
  * Added code search capabilities both for individual files and
    projects. The new functions are ``Project.search``,
    ``Project.complete_search``,  ``Script.search`` and
    ``Script.complete_search``.
  * Added ``Script.help`` to make it easier to display a help
    window to people. Now returns pydoc information as well for
    Python keywords/operators.  This means that on the class
    keyword it will now return the docstring of Python's builtin
    function ``help('class')``.
  * The API documentation is now way more readable and complete.
    Check it out under https://jedi.readthedocs.io. A lot of it
    has been rewritten.
  * Removed Python 3.4 support
  * Many bugfixes
- back to regular releases, no git service needed anymore
- jedi-pr1543-sorttest.patch gh#davidhalter/jedi#1543
* Mon Apr 13 2020 Benjamin Greiner <code@bnavigator.de>
- tell Leap 15.1 and SLE 15 SP1 pytest to ignore test/__init__.py
  so that a test file with purposely placed syntax errors does not
  trip the entire discovery
* Thu Apr  9 2020 Benjamin Greiner <code@bnavigator.de>
- reenable (most) unittests
- remove unbundle.patch -- according to upstream, typeshed is meant
  to be bundled.
* Tue Mar 17 2020 Benjamin Greiner <code@bnavigator.de>
- fix version string to 0.16.0+git55.17b3611c
* Mon Mar 16 2020 tchvatal@suse.com
- Update to version v0.16.0+git55.17b3611c:
  * Included statement as a possible return type for BaseDefinition.type
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable tests
* Sat Mar 14 2020 tchvatal@suse.com
- Update to version v0.16.0+git54.0888dd46:
  * Fix partialmethod issues
  * Make sure partialmethod tests are only executed for Python 3
  * Refactor stdlib PartialObject
  * Fix PartialMethodObject (WIP)
  * Changed semantics of ClassVar attributes in classes, fixes #1502
  * Avoid duplicate definitions for goto, fixes #1514
  * Merge _remove_statements and infer_expr_stmt, fixes #1504
  * Add partialmethod, fixes #1519
  * Attempt at a test of completion of filepath after ~.
  * Complete path after ~.
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove patches from git in preparation to switch to git service:
  * delete.patch
  * typing.patch
* Fri Mar  6 2020 Ondřej Súkup <mimi.vx@gmail.com>
- add typing.patch - fix test_sys_getwindowsversion with new parso
* Tue Feb  4 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.16.0
- add delete.patch
  * Added Script.get_context to get information where you currently are.
  * Completions/type inference of Pytest fixtures.
  * Tensorflow, Numpy and Pandas completions should now be about 4-10x faster after the first time they are used.
  * Dict key completions are working now. e.g. d = {1000: 3}; d[10 will expand to 1000.
  * Completion for “proxies” works now. These are classes that have a __getattr__(self, name) method that does a return getattr(x, name). after loading them initially.
  * Goto on a function/attribute in a class now goes to the definition in its super class.
  * Big Script API Changes:
  + The line and column parameters of jedi.Script are now deprecated
  + completions deprecated, use complete instead
  + goto_assignments deprecated, use goto instead
  + goto_definitions deprecated, use infer instead
  + call_signatures deprecated, use get_signatures instead
  + usages deprecated, use get_references instead
  + jedi.names deprecated, use jedi.Script(...).get_names()
  * BaseDefinition.goto_assignments renamed to BaseDefinition.goto
  * Add follow_imports to Definition.goto. Now its signature matches Script.goto.
  * Python 2 support deprecated. For this release it is best effort. Python 2 has reached the end of its life and now it’s just about a smooth transition. Bugs for Python 2 will not be fixed anymore and a third of the tests are already skipped.
  * Removed settings.no_completion_duplicates. It wasn’t tested and nobody was probably using it anyway.
  * Removed settings.use_filesystem_cache and settings.additional_dynamic_modules, they have no usage anymore. Pretty much nobody was probably using them.
* Sat Dec 28 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.15.2
- skip tests based on bundled typeshed
- refreshed unbundle.patch
  * Call signatures are now detected a lot better
  * Add fuzzy completions with Script(...).completions(fuzzy=True)
  * Files bigger than one MB (about 20kLOC) get cropped to avoid
    getting stuck completely.
  * A big refactoring around contexts/values
* Sat Nov 23 2019 Matej Cepl <mcepl@suse.com>
- So, this is completely boring, non-offensive changelog record,
  which says, that I have also add previously missing skip over
  test_compiled_signature test case, because of
  gh#davidhalter/jedi#1429
* Thu Oct 24 2019 Matej Cepl <mcepl@suse.com>
- Skip TestSetupReadline.test_import because of gh#davidhalter/jedi#1429
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip another time based test test_os_path_join
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip flaky test test_static_analysis
* Sun Aug 25 2019 Arun Persaud <arun@gmx.de>
- update to version 0.15.1:
  * Small bugfix and removal of a print statement
- changes from version 0.15.0:
  * Added file path completions, there's a new "Completion.type" path,
    now. Example: '/ho -> '/home/
  * *args/**kwargs resolving. If possible Jedi replaces the parameters
    with the actual alternatives.
  * Better support for enums/dataclasses
  * When using Interpreter, properties are now executed, since a lot
    of people have complained about this. Discussion in #1299, #1347.
  * New APIs:
    + Definition.get_signatures() -> List[Signature]. Signatures are
    similar to CallSignature. Definition.params is therefore
    deprecated.
    + Signature.to_string() to format call signatures.
    + Signature.params -> List[ParamDefinition], ParamDefinition has
    the following additional attributes infer_default(),
    infer_annotation(), to_string(), and kind.
    + Definition.execute() -> List[Definition], makes it possible to
    infer return values of functions.
* Tue Jul 16 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.14.1
  * CallSignature.index should now be working a lot better
  * A couple of smaller bugfixes
* Thu Jul  4 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.14.0
- enable tests
- add unbundle.patch
  * Added goto_*(prefer_stubs=True) as well as goto_*(prefer_stubs=True)
  * Stubs are used now for type inference
  * Typeshed is used for better type inference
  * Reworked Definition.full_name, should have more correct return values
* Wed May 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable tests as it is not working at all on python 3.7
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not bother condition for typing, on 3.7+ it is provided by base
* Sat Mar  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.3:
  * Fixed an issue with embedded Python see https://github.com/davidhalter/jedi-vim/issues/870
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix the typing dependency
- Really run the tests
* Sun Jan  6 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 0.13.2:
  * Fixed a bug that led to Jedi spawning a lot of subprocesses.
* Thu Oct 11 2018 Todd R <toddrme2178@gmail.com>
- update to version 0.13.1
  * Bugfixes, because tensorflow completions were still slow.
- update to version 0.13.0
  * A small release. Some bug fixes.
  * Remove Python 3.3 support. Python 3.3 support has been dropped by the Python
    foundation.
  * Default environments are now using the same Python version as the Python
    process. In 0.12.x, we used to load the latest Python version on the system.
  * Added ``include_builtins`` as a parameter to usages.
  * ``goto_assignments`` has a new ``follow_builtin_imports`` parameter that
    changes the previous behavior slightly.
- Remove test_requrements.patch, no longer needed
* Mon Jul  2 2018 arun@gmx.de
- specfile:
  * require parso >= 0.3.0
  * remove python-devel requirement
- update to version 0.12.1:
  * This release forces you to upgrade parso. If you don't, nothing
    will work anymore. Otherwise changes should be limited to bug
    fixes. Unfortunately Jedi still uses a few internals of parso that
    make it hard to keep compatibility over multiple releases. Parso
    >=0.3.0 is going to be needed.
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 0.12.0
  * Virtualenv/Environment support
  * F-String Completion/Goto Support
  * Cannot crash with segfaults anymore
  * Cleaned up import logic
  * Understand async/await and autocomplete it (including async generators)
  * Better namespace completions
  * Passing tests for Windows (including CI for Windows)
  * Remove Python 2.6 support
- Update to version 0.11.1
  * Parso update - the caching layer was broken
  * Better usages - a lot of internal code was ripped out and improved.
- Remove upstream-included test_requrements.patch
- Add new test_requrements.patch to avoid limit on pytest version.
- Disable tests, they don't work in most situations.
* Fri Nov 10 2017 mimi.vx@gmail.com
- fix requires
* Fri Nov 10 2017 mimi.vx@gmail.com
- fix tests to run on current python3
- added test_requrements.patch to allow newer versions of python-parso
* Fri Nov 10 2017 mimi.vx@gmail.com
- fix test conditions
* Tue Sep 26 2017 arun@gmx.de
- specfile:
  * require python-parso
  * require python-numpydoc for tests
- update to version 0.11.0:
  * Split Jedi's parser into a separate project called parso.
  * Avoiding side effects in REPL completion.
  * Numpy docstring support should be much better.
  * Moved the settings.*recursion* away, they are no longer usable.
* Mon Jun 19 2017 sebix+novell.com@sebix.at
- only require python3-typing if necessary
* Fri Apr 28 2017 jengelh@inai.de
- Grammatical corrections to description.
  Replace historic focus by current focus.
* Thu Apr 27 2017 toddrme2178@gmail.com
- Fix license.
* Thu Apr 27 2017 toddrme2178@gmail.com
- Disable tests on non-x86/x86_64 platforms.
* Tue Apr 25 2017 toddrme2178@gmail.com
- Update to version 0.10.2
  * Python Packaging sucks. Some files were not included in 0.10.1.
- Update to version 0.10.1
  * Fixed a few very annoying bugs.
  * Prepared the parser to be factored out of Jedi.
- Update to version 0.10.0
  * Actual semantic completions for the complete Python syntax.
  * Basic type inference for ``yield from`` PEP 380.
  * PEP 484 support (most of the important features of it).
  * Added ``get_line_code`` to ``Definition`` and ``Completion``
    objects.
  * Completely rewritten the type inference engine.
  * A new and better parser for (fast) parsing diffs of Python
    code.
- Implement single-spec version
* Thu Nov  5 2015 toddrme2178@gmail.com
- Fix tests
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.9.0:
  * The import logic has been rewritten to look more like Python's.
    There is now an Evaluator.modules import cache, which resembles
    sys.modules.
  * Integrated the parser of 2to3. This will make refactoring
    possible. It will also be possible to check for error messages
    (like compiling an AST would give) in the future.
  * With the new parser, the evaluation also completely changed.
    It's now simpler and more readable.
  * Completely rewritten REPL completion.
  * Added jedi.names, a command to do static analysis. Thanks to
    that sourcegraph guys for sponsoring this!
  * Alpha version of the linter.
- remove "-final0" appended to source version
- add python-unittest2 as a test dependency for SLE11
- skip failing tests in test_integration_import.py
* Wed Aug 13 2014 toddrme2178@gmail.com
- Update to version 0.8.1
  * Bugfix release, the last release forgot to include files that
    improve autocompletion for builtin libraries. Fixed.
- Update to version 0.8.0
  * Memory Consumption for compiled modules (e.g. builtins, sys)
    has been reduced drastically. Loading times are down as well
    (it takes basically as long as an import).
  * REPL completion is starting to become usable.
  * Various small API changes. Generally this released focuses on
    stability and refactoring of internal APIs.
  * Introducing operator precedence, which makes calculating
    correct Array indices and __getattr__ strings possible.
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.7.0
  * switched from LGPL to MIT license
  * added an Interpreter class to the API to make autocompletion
    in REPL possible.
  * added autocompletion support for namespace packages
  * add sith.py, a new random testing method
- Change License to MIT
- Drop old python3 stuff
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Aug 15 2013 mvyskocil@suse.com
- update to 0.6.0
  * Created find_module helper to handle compatibility with python 3.3
  * Fixed caching issues
  * More robust source encoding detection
  * Improved documentantion
  * and lot of bugfixes
- drop pre-checkin.sh
- drop a dependency on rpmbuild > 4.10, we don't need no ~ in version
* Thu May  9 2013 mvyskocil@suse.com
- package python3 variant via pre_checkin.sh
* Thu May  2 2013 mvyskocil@suse.com
- first packaging of jedi 0.5b5 for SUSE
